class ModelDot:
    """The ModelDot object can be used to access an actual MeshNode, ReferencePoint, or ConstrainedSketchVertex
    object.

    Notes
    -----
    This object can be accessed by:
    """

    ...
